import React, { useState, useEffect, useRef } from 'react';
import ProTable from '@ant-design/pro-table';
import { Form, Input, Select, InputNumber, TreeSelect, message, Button, Modal, Radio } from 'antd';
import quickAPI from "../../service";
import StepsButton from "../StepsButton";
import styles from "./index.less";
import indexStyles from "../../index.less";

const FoodMenuConfig = (props) => {

    const [ editFoodMenuForm ]  = Form.useForm();

    /**
     * 提交表单
     * @param {*} formValues
     */
    const onFinishSubmit = (formValues) => {
        props.onFinishForm('foodMenuConfig', formValues, true);
    }

    const [selectedRowsState, setSelectedRows] = useState(props.foodMenuConfig.id ? [props.foodMenuConfig] : []);
    const [selectedRowKeys, setSelectRowKeys] = useState(props.foodMenuConfig.id ? [props.foodMenuConfig.id] : []);

    const optionsWithDisabled = [
        {
            label: '新建菜谱',
            value: true,
        },
        {
            label: '选择菜谱',
            value: false,
        }
    ];

    const [isCreate, setIsCreate] = useState(props.foodMenuConfig.id ? false : true);

    const onChangeState = ({ target: { value } }) => {
        setIsCreate(value);
        let emptyObj = {
            id: "",
            code: "",
            name: ""
        }
        props.onFinishForm('foodMenuConfig', emptyObj);
        editFoodMenuForm.setFieldsValue(emptyObj);
        setSelectRowKeys([]);
        setSelectedRows([]);
    }
    const actionRef = useRef();
    const columns = [
        {
            title: '主键',
            dataIndex: 'id',
            hideInSearch: true,
            hideInTable: true,
            tip: '规则名称是唯一的 key'
        },
        {
            title: '菜谱编码',
            dataIndex: 'code',
            valueType: 'textarea',
        },
        {
            title: '菜谱名称',
            dataIndex: 'name',
            valueType: 'textarea',
        }
    ]

    return <>
        <div className={indexStyles.choose_change_state}>
            <Radio.Group
                options={optionsWithDisabled}
                onChange={onChangeState}
                value={isCreate}
                optionType="button"
                buttonStyle="solid"
            />
        </div>
        <div className={indexStyles.common_row}>
            <Form
                form={editFoodMenuForm}
                layout="Horizontal"
                preserve={false}
                initialValues={props.foodMenuConfig}
                onFinish={onFinishSubmit}
                style={{ width: '600px', marginRight: '30px' }}
            >
                <Form.Item name="id" hidden={true}>
                    <Input />
                </Form.Item>
                <Form.Item label={"菜谱编码"} name="code" rules={[{ required: true, max: 20 }]}>
                    <Input disabled={!isCreate || props.foodMenuConfig.id} />
                </Form.Item>
                <Form.Item label={"菜谱名称"} name="name" rules={[{ required: true, max: 20 }]} >
                    <Input disabled={!isCreate || props.foodMenuConfig.id} />
                </Form.Item>

                <Form.Item>
                    <StepsButton current={props.current} steps={props.steps} prev={props.prev}></StepsButton>
                </Form.Item>
            </Form>
            {
                !isCreate && <ProTable
                    headerTitle="菜谱列表"
                    actionRef={actionRef}
                    rowKey="id"
                    search={{
                        labelWidth: 120,
                    }}
                    request={async (params) => {
                        let data = [];
                        let total = 0;
                        await quickAPI.GetFoodMenuInfoPage(params).then((r) => {
                            data = r.data.data;
                            total = r.data.total;
                        });
                        return {
                            data: data,
                            success: true,
                            total: total,
                        };
                    }}
                    columns={columns}
                    rowSelection={{
                        type: 'radio',
                        onChange: (selectedRowKeys, selectedRows) => {
                            setSelectRowKeys(selectedRowKeys);
                            setSelectedRows(selectedRows);
                            if (selectedRows.length > 0) {
                                props.onFinishForm('foodMenuConfig', selectedRows[0]);
                                editFoodMenuForm.setFieldsValue(selectedRows[0]);
                            } else {
                                let emptyObj = {
                                    id: "",
                                    code: "",
                                    name: ""
                                }
                                editFoodMenuForm.setFieldsValue(emptyObj);
                                props.onFinishForm('foodMenuConfig', emptyObj);
                            }
                        },
                        selectedRowKeys: selectedRowKeys
                    }}
                />
            }
        </div>

    </>
}

export default FoodMenuConfig;