import React, { useState, useEffect, useRef } from 'react';
import { Form, Input, Select, InputNumber, TreeSelect, message, Radio } from 'antd';
import { ProTable } from '@ant-design/pro-table';
import StepsButton from "../StepsButton";
import quickAPI from "../../service";
import styles from "./index.less";

const StoreConfig = (props) => {

    const { TextArea } = Input;
    const { Option, OptGroup } = Select;
    const [storeForm] = Form.useForm();
    //组织树
    const [orgTree, setOrgTree] = useState([]);
    //支付方式列表
    const [payTypeList, setPayTypeList] = useState([]);

    //提交表单
    const onFinishSubmit = (formValues) => {
        props.onFinishForm('storeConfig', formValues, true);
    }

    const [isCreateStore, setIsCreateStore] = useState(props.storeConfig.id ? false : true);

    const optionsWithDisabled = [
        {
            label: '新建组织',
            value: true,
        },
        {
            label: '选择组织',
            value: false,
        }
    ];

    const onChangeState = ({ target: { value } }) => {
        storeForm.resetFields();
        setIsCreateStore(value);
        setSelectedRows([])
        setSelectRowKeys([]);
        if (value) {
            let emptyStore = {
                id: "",
                code: "",
                name: "",
                pid: "",
                type: 0,
                payTemplateId: "",
                store_Addr: "",
                store_Loc: "",
                tel: "",
                sort: 1,
                remark: ""
            }
            props.onFinishForm('storeConfig', emptyStore);
            storeForm.setFieldsValue(emptyStore);
            setSelectedRows([])
        }
    }

    const actionRef = useRef();

    //获取组织树
    const onFetchOrgTree = async () => {
        const response = await quickAPI.getOrgTree();
        if (response.statusCode === 200) {
            const org = [
                {
                    key: '0',
                    parentId: '0',
                    title: '顶级',
                    value: '0',
                    children: response.data || [],
                }
            ]
            setOrgTree(org);
        } else {
            message.error(response.errors || '获取组织架构出错');
        }
    }

    //获取支付配置
    const getPayTemplateList = async () => {
        const response = await quickAPI.getPayTemplateList();
        if (response.statusCode === 200) {
            setPayTypeList(response.data.data);
        } else {
            message.error(response.errors || '获取获取支付方式出错');
        }
    }

    //组织列表
    const columns = [
        {
            title: '主键',
            dataIndex: 'id',
            tip: 'key',
            hideInSearch: true,
            hideInTable: true,
        },
        {
            title: '组织名称',
            dataIndex: 'name',
        },
        {
            title: '组织类型',
            dataIndex: 'type',
            valueEnum: {
                0: {
                    text: '机构',
                },
                1: {
                    text: '配送中心',
                },
                2: {
                    text: '直营店',
                },
                3: {
                    text: '加盟店',
                },
            },
        }
    ];

    const [selectedRows, setSelectedRows] = useState(props.storeConfig.id ? [props.storeConfig] : []);
    const [selectedRowKeys, setSelectRowKeys] = useState(props.storeConfig.id ? [props.storeConfig.id] : []);

    /**
     * 选择组织
     */
    const rowSelection = {
        onChange: (selectedRowKeys, selectedRows) => {
            if (selectedRows.length > 0) {
                props.onFinishForm('storeConfig', selectedRows[0]);
                storeForm.setFieldsValue(selectedRows[0]);
                setSelectedRows(selectedRows);
                setSelectRowKeys(selectedRowKeys);
            } else {
                let emptyStore = {
                    id: "",
                    code: "",
                    name: "",
                    pid: "",
                    type: 0,
                    payTemplateId: "",
                    store_Addr: "",
                    store_Loc: "",
                    tel: "",
                    sort: 1,
                    remark: ""
                }
                props.onFinishForm('storeConfig', emptyStore);
                storeForm.setFieldsValue(emptyStore);
                setSelectedRows([])
                setSelectRowKeys([]);
            }
        },
        selectedRowKeys: selectedRowKeys
    };

    useEffect(() => {
        onFetchOrgTree();
        getPayTemplateList();
    }, []);

    return <div>
        <div className={styles.choose_store_state}>
            <Radio.Group
                options={optionsWithDisabled}
                onChange={onChangeState}
                value={isCreateStore}
                optionType="button"
                buttonStyle="solid"
            />
        </div>

        <div className={styles.store_config_container}>
            <Form
                form={storeForm}
                layout="horizontal"
                preserve={false}
                labelCol={{
                    span: 4,
                }}
                initialValues={props.storeConfig}
                style={{ width: '600px', marginRight: '50px' }}
                onFinish={onFinishSubmit}
            >
                <Form.Item name="id" hidden={true}>
                    <Input disabled={props.storeConfig.id || !isCreateStore} />
                </Form.Item>

                <Form.Item name="code" label="组织编码" rules={[{ required: true, max: 64 }]}>
                    <Input placeholder="请输入组织编码" disabled={props.storeConfig.id || !isCreateStore} />
                </Form.Item>

                <Form.Item name="name" label="组织名称" rules={[{ required: true, max: 64 }]}>
                    <Input placeholder="请输入名称" disabled={props.storeConfig.id || !isCreateStore} />
                </Form.Item>

                <Form.Item name="pid" label="上级名称" rules={[{ required: true }]}>
                    <TreeSelect
                        style={{ width: '100%' }}
                        dropdownStyle={{ maxHeight: 400, overflow: 'auto' }}
                        treeData={orgTree}
                        placeholder="请选择上级名称"
                        treeDefaultExpandAll
                        disabled={props.storeConfig.id || !isCreateStore}
                    />
                </Form.Item>

                <Form.Item
                    name="type"
                    label="组织类型"
                    rules={[{ required: true, message: '请选择组织类型' }]}
                >
                    <Select placeholder="请选择机构类型" disabled={props.storeConfig.id || !isCreateStore}>
                        <OptGroup>
                            <Select.Option value={0}>机构</Select.Option>
                            <Select.Option value={1}>配送中心</Select.Option>
                            <Select.Option value={2}>直营店</Select.Option>
                            <Select.Option value={3}>加盟店</Select.Option>
                        </OptGroup>
                    </Select>
                </Form.Item>

                <Form.Item
                    name="payTemplateId"
                    label="支付方式"
                >
                    <Select placeholder="请选择支付方式" disabled={props.storeConfig.id || !isCreateStore}>
                        {
                            payTypeList?.map(item => {
                                return <Option value={item.id} key={item.id}>{item.name}</Option>
                            })
                        }
                    </Select>
                </Form.Item>

                <Form.Item label={'店铺地址'} name="store_Addr" rules={[{ required: true, max: 100 }]}>
                    <Input placeholder="成都市武侯区桂溪街道环球中心N5-9111C" disabled={props.storeConfig.id || !isCreateStore} />
                </Form.Item>

                <Form.Item label={'店铺坐标'} name="store_Loc" rules={[{
                    required: true, max: 100, pattern: /^[-\+]?\d+(\.\d+)\,[-\+]?\d+(\.\d+)$/,
                    message: '经纬度格式不对'
                }]}>
                    <Input placeholder="104.070734,30.575041" disabled={props.storeConfig.id || !isCreateStore} />
                </Form.Item>

                <Form.Item name="tel" label="电话" rules={[{ max: 20 }]}>
                    <Input placeholder="请输入联系电话" disabled={props.storeConfig.id || !isCreateStore} />
                </Form.Item>

                <Form.Item name="sort" label="排序">
                    <InputNumber min={1} step={1} precision={0} disabled={props.storeConfig.id || !isCreateStore} />
                </Form.Item>

                <Form.Item name="remark" label="备注">
                    <TextArea rows={4} rules={[{ max: 500 }]} disabled={props.storeConfig.id || !isCreateStore} />
                </Form.Item>

                <Form.Item>
                    <StepsButton current={props.current} steps={props.steps}></StepsButton>
                </Form.Item>
            </Form>
            {
                !isCreateStore && <ProTable
                    headerTitle="组织列表"
                    actionRef={actionRef}
                    rowKey="id"
                    style={{ width: '600px' }}
                    rowSelection={{
                        type: 'radio',
                        ...rowSelection,
                    }}
                    request={async (params) => {
                        let UserData = [];
                        let total = 0;
                        await quickAPI.getpage(params).then((r) => {
                            UserData = r.data.data;
                            total = r.data.total;
                        });
                        return {
                            data: UserData,
                            success: true,
                            total: total,
                        };
                    }}
                    columns={columns}
                />
            }
        </div>
    </div>
}

export default StoreConfig;