import { Steps, Card } from 'antd';
import React, { useState, useEffect } from 'react';
import styles from "./index.less";
import { PageContainer } from '@ant-design/pro-layout';
import StoreConfig from './components/StoreConfig';
import DeviceConfig from './components/DeviceConfig';
import FoodMenuConfig from './components/FoodMenuConfig';
import GoodsConfig from './components/GoodsConfig';

const { Step } = Steps;

const QuickStart = () => {

    const [current, setCurrent] = useState(0);
    const [quickStartObj, setQuickStartObj] = useState({
        storeConfig: {
            id: "",
            code: "",
            name: "",
            pid: "",
            type: 0,
            payTemplateId: "",
            store_Addr: "",
            store_Loc: "",
            tel: "",
            sort: 1,
            remark: ""
        },
        deviceConfig: {
            id: "",
            deviceName: "",
            deviceTypeKey: "",
            orgId: "",
            deviceTypeId: "",
            deviceLoc: "",
            status: 0,
            materialQuantity: 1,
            deviceAddr: ""
        },
        foodMenuConfig: {
            id: "",
            code: "",
            name: ""
        },
        goodsConfig: {
            id: "",
            name: "",
            goodsUintId: "",
            price: 0,
            vipPrice: 0,
            parentTypeID: "",
            goodsTypeId: "",
            goodsAttribute: 0,
            status: 0,
            imgUrl: "",
            isWeigh: ""
        }
    });

    //每个页面点击下一步时触发
    const onFinishForm = (configType, payload, isNext = false) => {
        const tempQuick = JSON.parse(JSON.stringify(quickStartObj));
        const findKey = Object.keys(tempQuick).find(item => item === configType);
        if (findKey) {
            tempQuick[findKey] = payload;
            setQuickStartObj(tempQuick);
            if (isNext) {
                next();
            }
        }
    }

    //下一步
    const next = () => {
        setCurrent(current + 1);
    };

    //上一步
    const prev = () => {
        setCurrent(current - 1);
    };

    const stepsText = ['门店配置', '设备配置', '菜谱配置', '商品配置', '配方配置', '物料配置', '确认配置'];

    const stepsContent = [
        <StoreConfig storeConfig={quickStartObj.storeConfig} current={current} steps={stepsText} onFinishForm={onFinishForm}></StoreConfig>,
        <DeviceConfig deviceConfig={quickStartObj.deviceConfig} current={current} steps={stepsText} onFinishForm={onFinishForm} prev={prev}></DeviceConfig>,
        <FoodMenuConfig foodMenuConfig={quickStartObj.foodMenuConfig} current={current} steps={stepsText} onFinishForm={onFinishForm} prev={prev}></FoodMenuConfig>,
        <GoodsConfig goodsConfig={quickStartObj.goodsConfig} current={current} steps={stepsText} onFinishForm={onFinishForm} prev={prev}></GoodsConfig>,
        <h1>配方配置</h1>,
        <h1>物料配置</h1>,
        <h1>确认配置</h1>
    ];

    useEffect(() => {
        console.log('对象更新啦', quickStartObj);
    }, [quickStartObj]);

    return <PageContainer>
        <Card>
            <Steps current={current}>
                {stepsText.map((item) => (
                    <Step key={item} title={item} />
                ))}
            </Steps>
            <div className={styles.steps_content}>{stepsContent[current]}</div>
        </Card>
    </PageContainer>
}

export default QuickStart;